==> react-date-primitives-0.4.0.tgz: package/esm/CalendarMonth.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
// tslint:disable:max-line-length
import * as React from 'react';
import { startOfMonth, isDayAfter, isDayBefore, isSameDay, setMonth, getDatesofMonth } from './utils';
/**
 * Primitive react component that can be used show a month of make a datepicker.
 *
 * @example docs/examples/SimpleDatePicker.js
 */
var CalendarMonth = /** @class */ (function (_super) {
    __extends(CalendarMonth, _super);
    function CalendarMonth(props) {
        var _this = _super.call(this, props) || this;
        _this.getDropDowns = function (props) {
            var minDate = props.minDate, maxDate = props.maxDate, month = props.month;
            var firstDay = startOfMonth(month);
            var today = new Date();
            var minYear = minDate ? minDate.getFullYear() : today.getFullYear() - 50;
            var maxYear = maxDate ? maxDate.getFullYear() + 1 : today.getFullYear() + 5;
            var dropdownMonths = Array.from({ length: 12 }, function (_, i) { return ({
                disabled: Boolean((minDate && isDayBefore(setMonth(month, i), minDate)) ||
                    (maxDate && isDayAfter(setMonth(month, i), maxDate))),
                value: i,
                selected: firstDay.getMonth() === i
            }); });
            var dropdownYears = Array.from({ length: maxYear - minYear }, function (_, i) { return ({
                value: i + minYear,
                disabled: false,
                selected: i + minYear === firstDay.getFullYear()
            }); });
            return [dropdownMonths, dropdownYears];
        };
        if (props.showDropdowns) {
            var _a = _this.getDropDowns(props), dropdownMonths = _a[0], dropdownYears = _a[1];
            _this.monthsDropdown = dropdownMonths;
            _this.yearsDropdown = dropdownYears;
        }
        return _this;
    }
    CalendarMonth.prototype.componentWillReceiveProps = function (nextProps) {
        if (nextProps.showDropdowns) {
            var _a = this.getDropDowns(nextProps), dropdownMonths = _a[0], dropdownYears = _a[1];
            this.monthsDropdown = dropdownMonths;
            this.yearsDropdown = dropdownYears;
        }
        else {
            this.monthsDropdown = undefined;
            this.yearsDropdown = undefined;
        }
    };
    CalendarMonth.prototype.getDaysofMonth = function (props) {
        var month = props.month, startDate = props.startDate, endDate = props.endDate, minDate = props.minDate, maxDate = props.maxDate;
        var currentMonth = getDatesofMonth(month);
        var startDateDisabled = startDate && minDate && !isDayAfter(startDate, minDate);
        return currentMonth.map(function (week) {
            return week.map(function (day) {
                var date = day.date, inCurrentMonth = day.inCurrentMonth;
                var disabled = !inCurrentMonth ||
                    Boolean((minDate && isDayBefore(date, minDate)) ||
                        (maxDate && isDayAfter(date, maxDate)));
                return {
                    date: date,
                    inRange: inCurrentMonth &&
                        !startDateDisabled &&
                        !disabled &&
                        Boolean(startDate &&
                            isDayAfter(date, startDate) &&
                            endDate &&
                            isDayBefore(date, endDate)),
                    selected: !disabled &&
                        Boolean((startDate && isSameDay(date, startDate)) ||
                            (endDate && isSameDay(date, endDate))),
                    disabled: disabled,
                    inCurrentMonth: inCurrentMonth
                };
            });
        });
    };
    CalendarMonth.prototype.render = function () {
        var _a = this.props, month = _a.month, render = _a.render;
        return render({
            days: this.getDaysofMonth(this.props),
            month: startOfMonth(month),
            monthsDropdown: this.monthsDropdown,
            yearsDropdown: this.yearsDropdown
        });
    };
    return CalendarMonth;
}(React.Component));
export { CalendarMonth };

==> react-date-primitives-0.4.3.tgz: package/esm/CalendarMonth.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
// tslint:disable:max-line-length
import * as React from 'react';
import { startOfMonth, isDayAfter, isDayBefore, isSameDay, setMonth, getDatesofMonth } from './utils';
/**
 * Primitive react component that can be used show a month of make a datepicker.
 *
 * @example docs/examples/SimpleDatePicker.js
 */
var CalendarMonth = /** @class */ (function (_super) {
    __extends(CalendarMonth, _super);
    function CalendarMonth(props) {
        var _this = _super.call(this, props) || this;
        _this.getDropDowns = function (props) {
            var minDate = props.minDate, maxDate = props.maxDate, month = props.month;
            var firstDay = startOfMonth(month);
            var today = new Date();
            var minYear = minDate ? minDate.getFullYear() : today.getFullYear() - 50;
            var maxYear = maxDate ? maxDate.getFullYear() + 1 : today.getFullYear() + 5;
            var dropdownMonths = Array.from({ length: 12 }, function (_, i) { return ({
                disabled: Boolean((minDate && isDayBefore(setMonth(month, i), minDate)) ||
                    (maxDate && isDayAfter(setMonth(month, i), maxDate))),
                value: i,
                selected: firstDay.getMonth() === i
            }); });
            var dropdownYears = Array.from({ length: maxYear - minYear }, function (_, i) { return ({
                value: i + minYear,
                disabled: false,
                selected: i + minYear === firstDay.getFullYear()
            }); });
            return [dropdownMonths, dropdownYears];
        };
        if (props.showDropdowns) {
            var _a = _this.getDropDowns(props), dropdownMonths = _a[0], dropdownYears = _a[1];
            _this.monthsDropdown = dropdownMonths;
            _this.yearsDropdown = dropdownYears;
        }
        return _this;
    }
    CalendarMonth.prototype.componentWillReceiveProps = function (nextProps) {
        if (nextProps.showDropdowns) {
            var _a = this.getDropDowns(nextProps), dropdownMonths = _a[0], dropdownYears = _a[1];
            this.monthsDropdown = dropdownMonths;
            this.yearsDropdown = dropdownYears;
        }
        else {
            this.monthsDropdown = undefined;
            this.yearsDropdown = undefined;
        }
    };
    CalendarMonth.prototype.getDaysofMonth = function (props) {
        var month = props.month, startDate = props.startDate, endDate = props.endDate, minDate = props.minDate, maxDate = props.maxDate;
        var currentMonth = getDatesofMonth(month);
        var startDateDisabled = startDate && minDate && !(isSameDay(startDate, minDate) || isDayAfter(startDate, minDate));
        return currentMonth.map(function (week) {
            return week.map(function (day) {
                var date = day.date, inCurrentMonth = day.inCurrentMonth;
                var disabled = !inCurrentMonth ||
                    Boolean((minDate && isDayBefore(date, minDate)) ||
                        (maxDate && isDayAfter(date, maxDate)));
                return {
                    date: date,
                    inRange: inCurrentMonth &&
                        !startDateDisabled &&
                        !disabled &&
                        Boolean(startDate &&
                            isDayAfter(date, startDate) &&
                            endDate &&
                            isDayBefore(date, endDate)),
                    selected: !disabled &&
                        Boolean((startDate && isSameDay(date, startDate)) ||
                            (endDate && isSameDay(date, endDate))),
                    disabled: disabled,
                    inCurrentMonth: inCurrentMonth
                };
            });
        });
    };
    CalendarMonth.prototype.render = function () {
        var _a = this.props, month = _a.month, render = _a.render;
        return render({
            days: this.getDaysofMonth(this.props),
            month: startOfMonth(month),
            monthsDropdown: this.monthsDropdown,
            yearsDropdown: this.yearsDropdown
        });
    };
    return CalendarMonth;
}(React.Component));
export { CalendarMonth };
